@@ -64,7 +64,7 @@ def ts_toStr_det(stamp: int) -> str:
     :param stamp: 1577808000
     :return: '2020-01-01'
     """
-    return time.strftime("%Y-%m-%d", time.localtime(stamp))
+    return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(stamp))
 
 def datetime_toTimestamp(dateTime):
     """
@@ -234,13 +234,18 @@ def get_taobao_time():
         ts = requests.get(url)
         if ts.status_code == 200:
             json_data = json.loads(ts.text)
-            return {"sysTime2": timestamp_toString(json_data.get('time')),"sysTime1": f"{json_data.get('time')}"}
+            return {"sysTime3": ts_toStr_det(json_data.get('time')),
+                    "sysTime2": timestamp_toString(json_data.get('time')),
+                    "sysTime1": f"{json_data.get('time')}"}
         else:
-            json_data = {"sysTime2": datetime_toString_detail(datetime.datetime.now()),
+            json_data = {"sysTime3": ts_toStr_det(int(time.time())),
+                         "sysTime2": datetime_toString_detail(datetime.datetime.now()),
                          "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
             return json_data
     except:
-        json_data = {"sysTime2": datetime_toString_detail(datetime.datetime.now()),"sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
+        json_data = {"sysTime3": ts_toStr_det(int(time.time())),
+                     "sysTime2": datetime_toString_detail(datetime.datetime.now()),
+                     "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
         return json_data
 
 if __name__ == '__main__':
